@@ -1,7 +1,7 @@
 /* Main command processing loop.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2005 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -542,7 +542,7 @@ int do_action(buffer *b, action a, int c, unsigned char *p) {
 			free(b->find_string);
 			b->find_string = p;
 			b->find_string_changed = 1;
-			print_error(error = (a == FIND_A ? find : find_regexp)(b, NULL, 0, TRUE));
+			print_error(error = (a == FIND_A ? find : find_regexp)(b, NULL, 0, FALSE));
 		}
 
 		b->last_was_replace = 0;
