@@ -1,7 +1,7 @@
 /* Input line handling.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2005 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -167,6 +167,8 @@ static void init_history(void)
 							history_buff->opt.do_undo = 0;
 							history_buff->opt.auto_prefs = 0;
 							load_file_in_buffer(history_buff, history_filename);
+							/* The history buffer is agnostic. The actual encoding of each line is detected dynamically. */
+							history_buff->encoding = ENC_8_BIT;
 							change_filename(history_buff, str_dup(history_filename));
 							assert_buffer(history_buff);
 
