@@ -1,7 +1,7 @@
 /* Terminfo database scanning and keyboard escape sequence matching functions.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2005 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -322,6 +322,10 @@ void read_key_capabilities(void) {
 	key_may_set("\x1b[H",  NE_KEY_HOME);
 	key_may_set("\x1b[L",  NE_KEY_INSERT_CHAR);
 
+	/* gnome-terminal bizarre home/end keys */
+	key_may_set("\x1bOH",  NE_KEY_HOME);
+	key_may_set("\x1bOF",  NE_KEY_END);
+
 
 	/* The fundamental F1 escape key has been stolen by Gnome. We replace it
 		with a double escape, if possible. */
