@@ -1,7 +1,7 @@
 /* Requester handling.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2004 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2005 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -330,7 +330,9 @@ char *complete(const char *start_prefix) {
 	DIR *d;
 	struct dirent *de;
 	
-	if (!(cur_dir_name = ne_getcwd(CUR_DIR_MAX_SIZE))) return NULL;
+	/* This might be NULL if the current directory has been unlinked, or it is not readable.
+		in that case, we end up moving to the completion directory. */
+	cur_dir_name = ne_getcwd(CUR_DIR_MAX_SIZE);
 
 	if (dir_name = str_dup(start_prefix)) {
 		*(p = (char *)file_part(dir_name)) = 0;
@@ -365,8 +367,10 @@ char *complete(const char *start_prefix) {
 	   strcat(strcat(strcpy(result, dir_name), cur_prefix), unique && is_dir ? "/" : "");
 	}
 
-	chdir(cur_dir_name);
-	free(cur_dir_name);
+	if (cur_dir_name != NULL) {
+		chdir(cur_dir_name);
+		free(cur_dir_name);
+	}
 	free(dir_name);
 	free(cur_prefix);
 
